<?php
require_once(dirname(__FILE__).DIRECTORY_SEPARATOR.'ZpaymentException.php');
/**
 * Генерирует форму для запроса платежа.
 *
 * @package Zpaymentlib
 * @version $id$
 * @copyright 2014 by Z-Payment {@link http://www.z-payment.com}

 */
class ZpaymentRequestPaymentForm
{
    private $formData = array();
    private $formId = 'zpaymentForm';
    private $formMethod = 'post';
    private $formAction = 'https://www.z-payment.com/merchant.php';
    private $submitLabel = 'submit';
    private $autoSubmit = true;

    /**
     * Устанавливает идентификатор магазина в Zpayment через который совершается платеж.
     *
     * @param int $shopId
     * @access public
     * @return void
     */
    public function setShopId($shopId)
    {
        $this->formData['LMI_PAYEE_PURSE'] = $shopId;
    }

    /**
     * Устанавливает идентификатор покупки.
     *
     * @param mixed $shopPaymentId
     * @access public
     * @return void
     */
    public function setShopPaymentId($shopPaymentId)
    {
        $this->formData['LMI_PAYMENT_NO'] = $shopPaymentId;
    }

    /**
     * Устанавливает сумму платежа.
     *
     * @param float $amount
     * @access public
     * @return void
     */
    public function setAmount($amount)
    {
	    $amount=number_format($amount, 2, '.', ''); 
        $this->formData['LMI_PAYMENT_AMOUNT'] = $amount;
    }
	
    /**
     * Устанавливает подпись ZP_SIGN.
     */
    public function setZpsign($shopId, $shopPaymentId, $amount, $initPass)
    {
	    $amount=number_format($amount, 2, '.', ''); 
	    $zpsign=md5($shopId.$shopPaymentId.$amount.$initPass);
        $this->formData['ZP_SIGN'] = $zpsign;
    }

    /**
     * Устанавливает назначение платежа.
     *
     * @param string $purpose
     * @access public
     * @return void
     */
    public function setPurpose($purpose)
    {
        $this->formData['LMI_PAYMENT_DESC'] = $purpose;
    }

    /**
     * Устанавливает email пользователя осуществляющего платеж.
     *
     * @param string $userEmail
     * @access public
     * @return void
     */
    public function setUserEmail($userEmail)
    {
        $this->formData['CLIENT_EMAIL'] = $userEmail;
    }
    /**
     * Устанавливает метод отправки данных для формы запроса платежа.
     *
     * @param string $method
     * @access public
     * @return void
     */
    public function setMethod($method)
    {
        if ($method == 'get' || $method == 'post')
            $this->formMethod = $method;
        else
            throw new ZpaymentException('Unknown request method '.$method);
    }

    /**
     * Устанавливает текст кнопки для подтверждения формы.
     *
     * @param string $label
     * @access public
     * @return void
     */
    public function setSubmitLabel($label)
    {
        $this->submitLabel = $label;
    }

    /**
     * Включает автоматическое подтверждение формы запроса платежа.
     *
     * @access public
     * @return void
     */
    public function enableAutoSubmit()
    {
        $this->autoSubmit = true;
    }

    /**
     * Отключает автоматическое подтверждения формы.
     *
     * @access public
     * @return void
     */
    public function disableAutoSubmit()
    {
        $this->autoSubmit = false;
    }

    /**
     * Возвращает код формы запроса платежа.
     *
     * @access public
     * @return string
     */
    public function renderForm()
    {
        $form  = '<form id ="'.$this->formId.'" action="'.$this->formAction.'" method="'.$this->formMethod.'">';
        foreach ($this->formData as $name => $value)
            $form .= $this->renderInputField($name, $value);
        $form .= '<input type="hidden" name="src" value="1"/>';
        $form .= '<input type="submit" value="'.$this->submitLabel.'"/>';
        $form .= '</form>';
        if ($this->autoSubmit)
            $form .= '<script type="text/javascript"> document.forms["'.$this->formId.'"].submit(); </script>';
        return $form;
    }

    private function renderInputField($name, $value)
    {
        return '<input type="hidden" name="'.$name.'" value="'.$value.'" />';
    }
}
?>
